@@ -66,6 +66,7 @@ from flanker.addresslib.tokenizer import RBRACKET
 from flanker.addresslib.tokenizer import DQUOTE
 from flanker.addresslib.tokenizer import BAD_DOMAIN
 from flanker.addresslib.tokenizer import DELIMITER
+from flanker.addresslib.tokenizer import RELAX_ATOM
 from flanker.addresslib.tokenizer import WHITESPACE
 from flanker.addresslib.tokenizer import UNI_WHITE
 from flanker.addresslib.tokenizer import ATOM
@@ -106,6 +107,8 @@ class _AddressParser(object):
         # sanity check
         if not stream:
             raise ParserException('No input provided to parser.')
+        if isinstance(stream, str) and not is_pure_ascii(stream):
+            raise ParserException('ASCII string contains non-ASCII chars.')
 
         # to avoid spinning here forever, limit address list length
         if len(stream) > MAX_ADDRESS_LIST_LENGTH:
@@ -127,6 +130,8 @@ class _AddressParser(object):
         # sanity check
         if not stream:
             raise ParserException('No input provided to parser.')
+        if isinstance(stream, str) and not is_pure_ascii(stream):
+            raise ParserException('ASCII string contains non-ASCII chars.')
 
         # to avoid spinning here forever, limit mailbox length
         if len(stream) > MAX_ADDRESS_LENGTH:
@@ -154,6 +159,8 @@ class _AddressParser(object):
         # sanity check
         if stream is None:
             raise ParserException('No input provided to parser.')
+        if isinstance(stream, str) and not is_pure_ascii(stream):
+            raise ParserException('ASCII string contains non-ASCII chars.')
 
         # to avoid spinning here forever, limit mailbox length
         if len(stream) > MAX_ADDRESS_LENGTH:
@@ -173,6 +180,7 @@ class _AddressParser(object):
 
         return None
 
+
     def _mailbox_post_processing_checks(self, address):
         "Additional post processing checks to ensure mailbox is valid."
         parts = address.split('@')
@@ -550,7 +558,11 @@ class _AddressParser(object):
 
     def _word_ascii(self):
         "Grammar: word-ascii -> atom | qstring"
-        return self.stream.get_token(ATOM) or self.stream.get_token(QSTRING)
+        wrd = self.stream.get_token(RELAX_ATOM) or self.stream.get_token(QSTRING)
+        if wrd and not contains_control_chars(wrd):
+            return wrd
+
+        return None
 
     def _word_unicode(self):
         "Grammar: word-unicode -> unicode-atom | unicode-qstring"
@@ -558,14 +570,12 @@ class _AddressParser(object):
 
         # unicode atom
         uwrd = self.stream.get_token(UNI_ATOM)
-        if uwrd and isinstance(uwrd, unicode) and \
-            not contains_control_chars(uwrd) and not is_pure_ascii(uwrd):
+        if uwrd and isinstance(uwrd, unicode) and not contains_control_chars(uwrd):
             return uwrd
 
         # unicode qstr
         uwrd = self.stream.get_token(UNI_QSTR, 'qstr')
-        if uwrd and isinstance(uwrd, unicode) and \
-            not contains_control_chars(uwrd) and not is_pure_ascii(uwrd):
+        if uwrd and isinstance(uwrd, unicode) and not contains_control_chars(uwrd):
             return u'"{}"'.format(encode_string(None, uwrd))
 
         # rollback
